@@ -231,11 +231,12 @@ class B2GBrowser(Browser):
         timeout = 60
         while not has_connection():
             if time.time() - t0 > timeout:
+                self.logger.error("Waiting for net timed out")
                 raise BrowserError("Waiting for net timed out")
             time.sleep(1)
 
     def stop(self):
-        pass
+        self.logger.logcat(self.device.getLogcat())
 
     def cleanup(self):
         self.logger.debug("Running browser cleanup steps")
