@@ -238,15 +238,13 @@ class EqualTimeChunker(TestChunker):
 
 class TestFilter(object):
     def __init__(self, include=None, exclude=None, manifest_path=None):
-        if manifest_path is not None:
+        if manifest_path is not None and include is None:
             self.manifest = manifestinclude.get_manifest(manifest_path)
         else:
             self.manifest = manifestinclude.IncludeManifest.create()
 
-        if include or exclude:
-            self.manifest.set("skip", "true")
-
         if include is not None:
+            self.manifest.set("skip", "true")
             for item in include:
                 self.manifest.add_include(item)
 
